@@ -16,7 +16,7 @@ use Amazon::SNS::V4::Target;
 use Amazon::SNS::V4::Topic;
 use Amazon::SNS::V4::FifoTopic;
 
-our $VERSION = '1.11';
+our $VERSION = '2.0';
 
 
 sub CreateTopic
@@ -123,7 +123,7 @@ sub dispatch
 	$self->error(undef);
 	$self->error_response(undef);
 
-	$self->service('http://sns.eu-west-1.amazonaws.com')
+	$self->service('https://sns.eu-west-1.amazonaws.com')
 		unless defined $self->service;
 	$self->signer( AWS::Signature4->new(
 		-access_key => scalar $self->key,
@@ -238,78 +238,79 @@ Sorry for not providing a better documentation, patches are always accepted. ;)
 
 =head1 METHODS
 
-=over
+=head2 Amazon::SNS::V4->new({ 'key' => '...', 'secret' => '...' })
 
-=item Amazon::SNS::V4->new({ 'key' => '...', 'secret' => '...' })
+Creates an Amazon::SNS::V4 object with given key and secret.
 
-	Creates an Amazon::SNS::V4 object with given key and secret.
+=head2 $sns->GetTopic($arn)
 
-=item $sns->GetTopic($arn)
+Gives you an Amazon::SNS::V4::Topic object using an existing ARN.
 
-	Gives you an Amazon::SNS::V4::Topic object using an existing ARN.
+If your ARN refers to a FIFO Topic, gives you an Amazon::SNS::V4::FifoTopic object.
 
-=item $sns->GetTarget($arn)
+=head2 $sns->GetTarget($arn)
 
-	Gives you an Amazon::SNS::V4::Target object using an existing ARN. Sending Notification to TargetArn instead of TopicArn.
+Gives you an Amazon::SNS::V4::Target object using an existing ARN. Sending Notification to TargetArn instead of TopicArn.
 
-=item $sns->Publish($message, $subject, $attributes) (Amazon::SNS::V4::Target)
+=head2 $sns->Publish($message, $subject, $attributes) (Amazon::SNS::V4::Topic)
 
-	Additional parameter $attributes is used to pass MessageAttributes.entry.N attributes with message.
-	An example of MobilePush TTL: $attributes = {"AWS.SNS.MOBILE.APNS.TTL" => {"Type" => "String", "Value" => 3600}};
-	More information can be found on Amazon web site: http://docs.aws.amazon.com/sns/latest/dg/sns-ttl.html
+=head2 $sns->Publish($message, $subject, $attributes) (Amazon::SNS::V4::Target)
 
-=item $sns->CreateTopic($name)
+=head2 $sns->Publish($message, $subject, $attributes, $messagegroupid, $messagededupeid, $attributes) (Amazon::SNS::FifoTopic)
 
-	Gives you an Amazon::SNS::V4::Topic object with the given name, creating it 
-	if it does not already exist in your Amazon SNS account.
+Additional parameter $attributes is used to pass MessageAttributes.entry.N attributes with message.
+An example of MobilePush TTL: $attributes = {"AWS.SNS.MOBILE.APNS.TTL" => {"Type" => "String", "Value" => 3600}};
+More information can be found on Amazon web site: L<https://docs.aws.amazon.com/sns/latest/dg/sns-ttl.html>
 
-=item $sns->DeleteTopic($arn)
+$messagegroupid and $messagededupeid are for FIFO Topics, $messagegroupid is required, and $messagededupeid is required
+if the Topic has Content Based Deduplication disabled.  L<https://docs.aws.amazon.com/sns/latest/dg/fifo-message-dedup.html>
 
-	Deletes a topic using its ARN.
+=head2 $sns->CreateTopic($name)
 
-=item $sns->ListTopics
+Gives you an Amazon::SNS::V4::Topic object with the given name, creating it 
+if it does not already exist in your Amazon SNS account.
 
-	The result is a list of all the topics in your account, as an array of Amazon::SNS::V4::Topic objects.
+=head2 $sns->DeleteTopic($arn)
 
-=item $sns->error
+Deletes a topic using its ARN.
 
-	Description of the last error, or undef if none.
+=head2 $sns->ListTopics
 
-=item $sns->status_code
+The result is a list of all the topics in your account, as an array of Amazon::SNS::V4::Topic objects.
 
-	The status code of the last HTTP response.
+=head2 $sns->error
 
-=back
+Description of the last error, or undef if none.
+
+=head2 $sns->status_code
+
+The status code of the last HTTP response.
 
 =head1 ATTRIBUTES
 
-=over
+=head2 $sns->service
 
-=item $sns->service
+=head2 $sns->service($service_url)
 
-=item $sns->service($service_url)
+Get/set SNS service url, something like 'https://sns.us-east-1.amazonaws.com'.
 
-	Get/set SNS service url, something like 'http://sns.us-east-1.amazonaws.com'.
+=head2 $sns->key
 
-=item $sns->key
+=head2 $sns->key('...')
 
-=item $sns->key('...')
+Get/set auth key.
 
-	Get/set auth key.
+=head2 $sns->secret
 
-=item $sns->secret
+=head2 $sns->secret('...')
 
-=item $sns->secret('...')
+Get/set secret.
 
-	Get/set secret.
+=head2 $sns->debug
 
-=item $sns->debug
+=head2 $sns->debug(1)
 
-=item $sns->debug(1)
-
-	Get/set debug level. When set to 1 you'll get some debug output on STDERR.
-
-=back
+Get/set debug level. When set to 1 you'll get some debug output on STDERR.
 
 =head1 NOTES
 
@@ -332,15 +333,13 @@ L<AWS::Signature4>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2020 James Wright
+Copyright (C) 2020-2021 James Wright
 
 Copyright (C) 2011-15 Alessandro Zummo
 
-
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License version 2 as
 published by the Free Software Foundation.
 
-
 =cut
 
